summaryrefslogtreecommitdiffstats
path: root/kmymoney2/dialogs/investtransactioneditor.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit6612bcfa1e491fbb2f441f2060f700b6ad589ffd (patch)
tree01ab5692b3735b315708ecef00f3a1a3d3e07d51 /kmymoney2/dialogs/investtransactioneditor.cpp
parent6aa61ac2c4eb5a0c0882b2255a9dd6789a428bc7 (diff)
downloadkmymoney-6612bcfa1e491fbb2f441f2060f700b6ad589ffd.tar.gz
kmymoney-6612bcfa1e491fbb2f441f2060f700b6ad589ffd.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kmymoney@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmymoney2/dialogs/investtransactioneditor.cpp')
-rw-r--r--kmymoney2/dialogs/investtransactioneditor.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmymoney2/dialogs/investtransactioneditor.cpp b/kmymoney2/dialogs/investtransactioneditor.cpp
index d235ae5..e19a756 100644
--- a/kmymoney2/dialogs/investtransactioneditor.cpp
+++ b/kmymoney2/dialogs/investtransactioneditor.cpp
@@ -801,10 +801,10 @@ void InvestTransactionEditor::slotUpdateActivity(MyMoneySplit::investTransaction
KMyMoneyCategory* cat;
// hide all dynamic widgets (make sure to use the tqparentWidget for the
// category widgets)
- haveWidget("interest-account")->tqparentWidget()->hide();
- haveWidget("fee-account")->tqparentWidget()->hide();
+ haveWidget("interest-account")->parentWidget()->hide();
+ haveWidget("fee-account")->parentWidget()->hide();
TQStringList dynwidgets;
dynwidgets << "total-label" << "asset-label" << "fee-label" << "fee-amount-label" << "interest-label" << "interest-amount-label" << "price-label" << "shares-label";
@@ -833,11 +833,11 @@ void InvestTransactionEditor::slotUpdateActivity(MyMoneySplit::investTransaction
d->m_activity->preloadAssetAccount();
cat = dynamic_cast<KMyMoneyCategory*>(haveWidget("interest-account"));
- if(cat->tqparentWidget()->isVisible())
+ if(cat->parentWidget()->isVisible())
slotUpdateInterestVisibility(cat->currentText());
cat = dynamic_cast<KMyMoneyCategory*>(haveWidget("fee-account"));
- if(cat->tqparentWidget()->isVisible())
+ if(cat->parentWidget()->isVisible())
slotUpdateFeeVisibility(cat->currentText());
}
@@ -854,7 +854,7 @@ InvestTransactionEditor::priceModeE InvestTransactionEditor::priceMode(void) con
while(!accId.isEmpty() && mode == 0) {
MyMoneyAccount acc = MyMoneyFile::instance()->account(accId);
if(acc.value("priceMode").isEmpty())
- accId = acc.tqparentAccountId();
+ accId = acc.parentAccountId();
else
mode = static_cast<priceModeE>(acc.value("priceMode").toInt());
}
@@ -801,10 +801,10 @@ void InvestTransactionEditor::slotUpdateActivity(MyMoneySplit::investTransaction
KMyMoneyCategory* cat;
- // hide all dynamic widgets (make sure to use the tqparentWidget for the
+ // hide all dynamic widgets (make sure to use the parentWidget for the
// category widgets)